@@ -26,14 +26,22 @@
 /*   }; */
 /* } */
 
+/// \cond expat
+
 namespace expat {
 #include "../../Common/Expat/lib/expat.h"
 }
 
+/// \endcond
+
 namespace Dasher {
   class CAlphIO;
 } 
 
+
+/// \ingroup Alphabet
+/// @{
+
 class Dasher::CAlphIO {
 public:
   // This structure completely describes the characters used in alphabet
@@ -77,15 +85,12 @@ public:
     character ParagraphCharacter;       // display and edit text of paragraph character. Use ("", "") if no paragraph character.
     character SpaceCharacter;   // display and edit text of Space character. Typically (" ", "_"). Use ("", "") if no space character.
     character ControlCharacter; // display and edit text of Control character. Typically ("", "Control"). Use ("", "") if no control character.
-
-    // Added for Kanji Conversion by T.Kaburagi 15 July 2005
     character StartConvertCharacter;
     character EndConvertCharacter;
+    int m_iConversionID;
+    std::string m_strDefaultContext;
   };
 
-
-  
-
   CAlphIO(std::string SystemLocation, std::string UserLocation, std::vector < std::string > Filenames);
   void GetAlphabets(std::vector < std::string > *AlphabetList) const;
   std::string GetDefault();
@@ -119,6 +124,7 @@ private:
   std::string CData;            // Text gathered from when an elemnt starts to when it ends
   AlphInfo InputInfo;
   bool bFirstGroup;
+  int iGroupIdx;
 
   // Callback functions. These involve the normal dodgy casting to a pointer
   // to an instance to get a C++ class to work with a plain C library.
@@ -127,4 +133,6 @@ private:
   static void XML_CharacterData(void *userData, const expat::XML_Char * s, int len);
 };
 
+/// @}
+
 #endif /* #ifndef __AlphIO_h__ */
