@@ -173,11 +173,34 @@ void CDasherModel::Make_root(CDasherNode *pNewRoot) {
   // existing data structure?
   oldroots.push_back(m_Root);
 
-  while((oldroots.size() > 10) && (!m_bRequireConversion || (oldroots[0]->GetFlag(NF_CONVERTED)))) {
-    oldroots[0]->OrphanChild(oldroots[1]);
-    delete oldroots[0];
-    oldroots.pop_front();
+  // Clear roots...
+  // First figure out how many we can get rid of
+
+  int iOldRootSize(oldroots.size());
+  int iMaxHead(iOldRootSize - 10);
+  
+  int iMinHead(0);
+
+  for(int i(1); i <= iMaxHead; ++i) {
+    if((!m_bRequireConversion || (oldroots[i]->GetFlag(NF_CONVERTED))) &&
+       !(oldroots[i]->GetFlag(NF_SUBNODE)))
+      iMinHead = i;
   }
+    
+  if(iMinHead > 0) {
+    for(int i(0); i < iMinHead; ++i) {
+      oldroots[0]->OrphanChild(oldroots[1]);
+      delete oldroots[0];
+      oldroots.pop_front();
+    }
+  }
+    
+
+//   while((oldroots.size() > 10) && (!m_bRequireConversion || (oldroots[0]->GetFlag(NF_CONVERTED)))) {
+//     oldroots[0]->OrphanChild(oldroots[1]);
+//     delete oldroots[0];
+//     oldroots.pop_front();
+//   }
 
   m_Root = pNewRoot;
 
@@ -245,6 +268,8 @@ void CDasherModel::Reparent_root(int lower, int upper) {
     pNewRoot = oldroots.back();
     oldroots.pop_back();
 
+    DASHER_ASSERT(!((oldroots.front())->GetFlag(NF_SUBNODE)));
+
     while((oldroots.size() > 0) && pNewRoot->GetFlag(NF_SUBNODE)) {
       pNewRoot = oldroots.back();
       oldroots.pop_back();
@@ -346,6 +371,8 @@ void CDasherModel::InitialiseAtOffset(int iOffset, CDasherView *pView) {
     delete[] oData.szContext;
   }
 
+  m_pLastOutput = m_Root;
+
   // Create children of the root
   // TODO: What about parents?
 
@@ -355,7 +382,6 @@ void CDasherModel::InitialiseAtOffset(int iOffset, CDasherView *pView) {
   // size and we're not in any of the children
 
   double dFraction( 1 - (1 - m_Root->MostProbableChild() / static_cast<double>(GetLongParameter(LP_NORMALIZATION))) / 2.0 );
-
   int iWidth( static_cast<int>( (GetLongParameter(LP_MAX_Y) / (2.0*dFraction)) ) );
 
   m_Rootmin = GetLongParameter(LP_MAX_Y) / 2 - iWidth / 2;
@@ -606,11 +632,13 @@ void CDasherModel::NewGoTo(myint newRootmin, myint newRootmax, Dasher::VECTOR_SY
 
 void CDasherModel::HandleOutput(CDasherNode *pNewNode, CDasherNode *pOldNode, Dasher::VECTOR_SYMBOL_PROB* pAdded, int* pNumDeleted) {
   DASHER_ASSERT(pNewNode != NULL);
-  DASHER_ASSERT(pOldNode != NULL);
+  //  DASHER_ASSERT(pOldNode != NULL);
   
-  if(pNewNode != pOldNode)
-    DeleteCharacters(pNewNode, pOldNode, pNumDeleted);
+  if(pNewNode != m_pLastOutput)
+    DeleteCharacters(pNewNode, m_pLastOutput, pNumDeleted);
   
+  m_pLastOutput = pNewNode;
+
   if(pNewNode->GetFlag(NF_SEEN))
     return;
 
@@ -624,22 +652,16 @@ bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode,
   // This deals with the trivial instance - we're reversing back over
   // text that we've seen already
   if(newnode->GetFlag(NF_SEEN)) {
-    if(oldnode->Parent() == newnode) {
-      oldnode->m_pNodeManager->Undo(oldnode);
-      oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
-      if (pNumDeleted != NULL)
-        (*pNumDeleted)++;
-      oldnode->SetFlag(NF_SEEN, false);
-      return true;
-    }
-    if(DeleteCharacters(newnode, oldnode->Parent(), pNumDeleted) == true) {
-      oldnode->m_pNodeManager->Undo(oldnode);
-      oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
-      if (pNumDeleted != NULL)
-	(*pNumDeleted)++;
-      oldnode->SetFlag(NF_SEEN, false);
-      return true;
-    }
+    oldnode->m_pNodeManager->Undo(oldnode);
+    oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
+    if (pNumDeleted != NULL)
+      (*pNumDeleted)++;
+    oldnode->SetFlag(NF_SEEN, false);
+
+    if(oldnode->Parent() != newnode)
+      DeleteCharacters(newnode, oldnode->Parent(), pNumDeleted);
+
+    return true;
   }
   else {
     // This one's more complicated - the user may have moved onto a new branch
