@@ -10,12 +10,13 @@ static void dasher_internal_buffer_destroy(GObject *pObject);
 static void idasher_buffer_set_interface_init (gpointer g_iface, gpointer iface_data);
 void dasher_internal_buffer_insert(DasherInternalBuffer *pSelf, const gchar *szText);
 void dasher_internal_buffer_delete(DasherInternalBuffer *pSelf, int iLength);
-gchar *dasher_internal_buffer_get_context(DasherInternalBuffer *pSelf, gint iMaxLength);
+gchar *dasher_internal_buffer_get_context(DasherInternalBuffer *pSelf, gint iOffset, gint iLength);
 void dasher_internal_buffer_edit_move(DasherInternalBuffer *pSelf, int iDirection, int iDist);
 void dasher_internal_buffer_edit_delete(DasherInternalBuffer *pSelf, int iDirection, int iDist);
 void dasher_internal_buffer_edit_convert(DasherInternalBuffer *pSelf);
 void dasher_internal_buffer_edit_protect(DasherInternalBuffer *pSelf);
 void dasher_internal_buffer_conversion_mode(DasherInternalBuffer *pSelf, gboolean bMode);
+gint dasher_internal_buffer_get_offset(DasherInternalBuffer *pSelf);
 
 // Related signal handlers
 extern "C" void mark_set_handler(GtkWidget *widget, GtkTextIter *pIter, GtkTextMark *pMark, gpointer pUserData);
@@ -80,12 +81,13 @@ static void idasher_buffer_set_interface_init (gpointer g_iface, gpointer iface_
   IDasherBufferSetInterface *iface = (IDasherBufferSetInterface *)g_iface;
   iface->insert_text = (void (*)(IDasherBufferSet *pSelf, const gchar *szText))dasher_internal_buffer_insert;
   iface->delete_text = (void (*)(IDasherBufferSet *pSelf, gint iLength))dasher_internal_buffer_delete;
-  iface->get_context = (gchar *(*)(IDasherBufferSet *pSelf, gint iMaxLength))dasher_internal_buffer_get_context;
+  iface->get_context = (gchar *(*)(IDasherBufferSet *pSelf, gint iOffset, gint iLength))dasher_internal_buffer_get_context;
   iface->edit_move = (void (*)(IDasherBufferSet *pSelf, gint iDirection, gint iDist))dasher_internal_buffer_edit_move;
   iface->edit_delete = (void (*)(IDasherBufferSet *pSelf, gint iDirection, gint iDist))dasher_internal_buffer_edit_delete;
   iface->edit_convert = (void (*)(IDasherBufferSet *pSelf))dasher_internal_buffer_edit_convert;
   iface->edit_protect = (void (*)(IDasherBufferSet *pSelf))dasher_internal_buffer_edit_protect;
   iface->conversion_mode = (void (*)(IDasherBufferSet *pSelf, gboolean bMode))dasher_internal_buffer_conversion_mode;
+  iface->get_offset = (gint (*)(IDasherBufferSet *pSelf))dasher_internal_buffer_get_offset;
 }
 
 static void dasher_internal_buffer_destroy(GObject *pObject) {
@@ -175,15 +177,14 @@ void dasher_internal_buffer_delete(DasherInternalBuffer *pSelf, int iLength) {
   delete end;
 }
 
-gchar *dasher_internal_buffer_get_context(DasherInternalBuffer *pSelf, gint iMaxLength) {
+gchar *dasher_internal_buffer_get_context(DasherInternalBuffer *pSelf, gint iOffset, gint iLength) {
   DasherInternalBufferPrivate *pPrivate = (DasherInternalBufferPrivate *)(pSelf->private_data);
 
   GtkTextIter start;
   GtkTextIter end; // Refers to end of context, which is start of selection!
 
-  gtk_text_buffer_get_selection_bounds( pPrivate->pBuffer, &end, NULL );
-  start = end;
-  gtk_text_iter_backward_chars( &start, iMaxLength );
+  gtk_text_buffer_get_iter_at_offset(pPrivate->pBuffer, &start, iOffset);
+  gtk_text_buffer_get_iter_at_offset(pPrivate->pBuffer, &end, iOffset + iLength);
 
   return gtk_text_buffer_get_text( pPrivate->pBuffer, &start, &end, false );
 }
@@ -191,7 +192,7 @@ gchar *dasher_internal_buffer_get_context(DasherInternalBuffer *pSelf, gint iMax
 void dasher_internal_buffer_change_context(DasherInternalBuffer *pSelf, GtkTextIter *pIter, GtkTextMark *pMark) {
   const char *szMarkName(gtk_text_mark_get_name(pMark));
   if(szMarkName && !strcmp(szMarkName,"insert")) {
-    g_signal_emit(pSelf, idasher_buffer_set_signals[CONTEXT_CHANGED], 0, NULL);
+    g_signal_emit_by_name(G_OBJECT(pSelf), "context_changed", G_OBJECT(pSelf), NULL, NULL);
   }
 }
 
@@ -349,12 +350,22 @@ void dasher_internal_buffer_clear(DasherInternalBuffer *pSelf) {
 
   gtk_text_buffer_delete(pPrivate->pBuffer, start, end);
 
-  g_signal_emit(pSelf, idasher_buffer_set_signals[CONTEXT_CHANGED], 0, NULL);
+  /* TODO: this probably shouldn't emit a signal */
+  g_signal_emit_by_name(G_OBJECT(pSelf), "context_changed", G_OBJECT(pSelf), NULL, NULL);
 
   pPrivate->iCurrentState = 0;
   pPrivate->iLastOffset = 0;
 }
 
+gint dasher_internal_buffer_get_offset(DasherInternalBuffer *pSelf) {
+  DasherInternalBufferPrivate *pPrivate = (DasherInternalBufferPrivate *)(pSelf->private_data);
+ 
+  GtkTextIter oIter;
+  gtk_text_buffer_get_iter_at_mark(pPrivate->pBuffer, &oIter, gtk_text_buffer_get_mark(pPrivate->pBuffer, "insert"));
+  return gtk_text_iter_get_offset(&oIter);
+}
+
+
 // Handlers
 
 extern "C" void mark_set_handler(GtkWidget *widget, GtkTextIter *pIter, GtkTextMark *pMark, gpointer pUserData) {
